==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/ListDiagnosticSettingsCategoryPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.ListDiagnosticSettingsCategoryPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceUri The identifier of the resource.
 */
public data class ListDiagnosticSettingsCategoryPlainArgs(
    public val resourceUri: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.insights.inputs.ListDiagnosticSettingsCategoryPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.insights.inputs.ListDiagnosticSettingsCategoryPlainArgs =
        com.pulumi.azurenative.insights.inputs.ListDiagnosticSettingsCategoryPlainArgs.builder()
            .resourceUri(resourceUri.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListDiagnosticSettingsCategoryPlainArgs].
 */
@PulumiTagMarker
public class ListDiagnosticSettingsCategoryPlainArgsBuilder internal constructor() {
    private var resourceUri: String? = null

    /**
     * @param value The identifier of the resource.
     */
    @JvmName("veevjtrwbfkxpdhk")
    public suspend fun resourceUri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceUri = mapped
    }

    internal fun build(): ListDiagnosticSettingsCategoryPlainArgs =
        ListDiagnosticSettingsCategoryPlainArgs(
            resourceUri = resourceUri ?: throw PulumiNullFieldException("resourceUri"),
        )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/ListDiagnosticSettingsCategoryPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.ListDiagnosticSettingsCategoryPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceUri The identifier of the resource.
 */
public data class ListDiagnosticSettingsCategoryPlainArgs(
    public val resourceUri: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.insights.inputs.ListDiagnosticSettingsCategoryPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.ListDiagnosticSettingsCategoryPlainArgs =
        com.pulumi.azurenative.insights.inputs.ListDiagnosticSettingsCategoryPlainArgs.builder()
            .resourceUri(resourceUri.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListDiagnosticSettingsCategoryPlainArgs].
 */
@PulumiTagMarker
public class ListDiagnosticSettingsCategoryPlainArgsBuilder internal constructor() {
    private var resourceUri: String? = null

    /**
     * @param value The identifier of the resource.
     */
    @JvmName("woqbwyjuxgsserga")
    public suspend fun resourceUri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceUri = mapped
    }

    internal fun build(): ListDiagnosticSettingsCategoryPlainArgs =
        ListDiagnosticSettingsCategoryPlainArgs(
            resourceUri = resourceUri ?: throw PulumiNullFieldException("resourceUri"),
        )
}
